@@ -46,15 +46,7 @@ impl ShardedGossipLocal {
             // a stale accept comes in for the same peer cert?
             // Maybe we need to check timestamps on messages or have unique round ids?
             inner.round_map.insert(peer_cert.clone(), state);
-            // If this is not the target we are accepting
-            // then record it as a remote round.
-            if inner
-                .initiate_tgt
-                .as_ref()
-                .map_or(true, |tgt| *tgt.0.cert() != peer_cert)
-            {
-                inner.metrics.record_remote_round(peer_cert);
-            }
+            inner.metrics.record_initiate(peer_cert);
             Ok(())
         })?;
         Ok(gossip)
