@@ -17,10 +17,7 @@ impl ShardedGossipLocal {
         // Get the time range for this gossip.
         // Get all the agent info that is within the common arc set.
         let agents_within_arc: Vec<_> =
-            store::agent_info_within_arc_set(&self.evt_sender, &self.space, common_arc_set)
-                .await?
-                // Need to collect to know the length for the bloom filter.
-                .collect();
+            get_agent_info(&self.evt_sender, &self.space, common_arc_set).await?;
 
         // There was no agents so we don't create a bloom.
         if agents_within_arc.is_empty() {
@@ -61,6 +58,7 @@ impl ShardedGossipLocal {
                     .await?
                     .into_iter()
                     .filter(|(a, _)| local_agents.contains(a))
+                    .filter(|(_, i)| !i.is_empty())
                     .collect();
 
             // Get the op hashes which fit within the common arc set from these local agents.
@@ -192,3 +190,14 @@ impl ShardedGossipLocal {
         }
     }
 }
+
+async fn get_agent_info(
+    evt_sender: &EventSender,
+    space: &Arc<KitsuneSpace>,
+    arc_set: Arc<DhtArcSet>,
+) -> KitsuneResult<Vec<AgentInfoSigned>> {
+    Ok(store::agent_info_within_arc_set(evt_sender, space, arc_set)
+        .await?
+        // Need to collect to know the length for the bloom filter.
+        .collect())
+}
